A R6 class to represent a Gumbel distribution.
aGet or set the value of a.
bGet or set the value of b.
new()New Gumbel distribution.
Gumbel$new(a, b)alocation parameter
bscale parameter, >0
A Gumbel object.
d()Density function of the Gumbel distribution.
Gumbel$d(x, log = FALSE)xnumeric vector
logBoolean, whether to return the logarithm of the density
The density or the log-density evaluated at x.
p()Cumulative distribution function of the Gumbel distribution.
Gumbel$p(q, lower = TRUE)qnumeric vector of quantiles
lowerBoolean, whether to deal with the lower tail
The cumulative probabilities corresponding to q.
pnumeric vector of probabilities
lowerBoolean, whether to deal with the lower tail
The quantiles corresponding to p.
r()Sampling from the Gumbel distribution.
Gumbel$r(n)nnumber of simulations
A numeric vector of length n.
The mean of the Gumbel distribution.
The median of the Gumbel distribution.
The mode of the Gumbel distribution.
The standard deviation of the Gumbel distribution.
variance()Variance of the Gumbel distribution.
Gumbel$variance()The variance of the Gumbel distribution.
skewness()Skewness of the Gumbel distribution.
Gumbel$skewness()The skewness of the Gumbel distribution.
kurtosis()Kurtosis of the Gumbel distribution.
Gumbel$kurtosis()The kurtosis of the Gumbel distribution.
kurtosisExcess()Kurtosis excess of the Gumbel distribution.
Gumbel$kurtosisExcess()The kurtosis excess of the Gumbel distribution.
clone()The objects of this class are cloneable with this method.
Gumbel$clone(deep = FALSE)deepWhether to make a deep clone.
See Wikipedia.