A R6 class to represent a hyperexponential distribution.
probsGet or set the value of probs.
ratesGet or set the value of rates.
new()New hyperexponential distribution.
Hyperexponential$new(probs, rates)probsprobabilities (weights), a vector of positive numbers
ratesrate parameters, vector of positive numbers of the same
length as the probs vector
A Hyperexponential object.
d()Density function of the hyperexponential distribution.
Hyperexponential$d(x)xvector of positive numbers
The density evaluated at x.
p()Cumulative distribution function of the hyperexponential distribution.
Hyperexponential$p(q, lower = TRUE)qnumeric vector of quantiles
lowerBoolean, whether to deal with the lower tail
The cumulative probabilities corresponding to q.
q()Quantile function of the hyperexponential distribution.
Hyperexponential$q(p, lower = TRUE)pnumeric vector of probabilities
lowerBoolean, whether to deal with the lower tail
The quantiles corresponding to p.
r()Sampling from the hyperexponential distribution.
Hyperexponential$r(n)nnumber of simulations
A numeric vector of length n.
The mean of the hyperexponential distribution.
The mode of the hyperexponential distribution.
The standard deviation of the hyperexponential distribution.
variance()Variance of the hyperexponential distribution.
Hyperexponential$variance()The variance of the hyperexponential distribution.
skewness()Skewness of the hyperexponential distribution.
Hyperexponential$skewness()The skewness of the hyperexponential distribution.
kurtosis()Kurtosis of the hyperexponential distribution.
Hyperexponential$kurtosis()The kurtosis of the hyperexponential distribution.
kurtosisExcess()Kurtosis excess of the hyperexponential distribution.
Hyperexponential$kurtosisExcess()The kurtosis excess of the hyperexponential distribution.
clone()The objects of this class are cloneable with this method.
Hyperexponential$clone(deep = FALSE)deepWhether to make a deep clone.
See Wikipedia.