A R6 class to represent an inverse Gaussian distribution.
muGet or set the value of mu.
lambdaGet or set the value of lambda.
new()New inverse Gaussian distribution.
InverseGaussian$new(mu, lambda)muparameter, the mean, >0
lambdashape parameter, >0
An inverseGaussian object.
d()Density function of the inverse Gaussian distribution.
InverseGaussian$d(x, log = FALSE)xvector of positive numbers
logBoolean, whether to return the logarithm of the density
The density or the log-density evaluated at x.
p()Cumulative distribution function of the inverse Gaussian distribution.
InverseGaussian$p(q, lower = TRUE)qnumeric vector of quantiles
lowerBoolean, whether to deal with the lower tail
The cumulative probabilities corresponding to q.
q()Quantile function of the inverse Gaussian distribution.
InverseGaussian$q(p, lower = TRUE)pnumeric vector of probabilities
lowerBoolean, whether to deal with the lower tail
The quantiles corresponding to p.
r()Sampling from the inverse Gaussian distribution.
InverseGaussian$r(n)nnumber of simulations
A numeric vector of length n.
The mean of the inverse Gaussian distribution.
The median of the inverse Gaussian distribution.
The mode of the inverse Gaussian distribution.
The standard deviation of the inverse Gaussian distribution.
variance()Variance of the inverse Gaussian distribution.
InverseGaussian$variance()The variance of the inverse Gaussian distribution.
skewness()Skewness of the inverse Gaussian distribution.
InverseGaussian$skewness()The skewness of the inverse Gaussian distribution.
kurtosis()Kurtosis of the inverse Gaussian distribution.
InverseGaussian$kurtosis()The kurtosis of the inverse Gaussian distribution.
kurtosisExcess()Kurtosis excess of the inverse Gaussian distribution.
InverseGaussian$kurtosisExcess()The kurtosis excess of the inverse Gaussian distribution.
clone()The objects of this class are cloneable with this method.
InverseGaussian$clone(deep = FALSE)deepWhether to make a deep clone.
See Wikipedia.